#!/bin/bash
###############################################################
#                                                             #
#       Format:  s1-convertnotags.sh module_name              #
#                                                             #
# input: CVS module name as an argument (module_name)         #
# output: a bazaar repository in /bzrrepo/module_name         #
#                                                             #
# before starting verify:                                     #
# 1. Conversion options file  have the correct references to  #
#    the module name:                                         #
# - cvs2bzr-MODULE.options                                    #
# 2. There is no bzr repository in the ./bzrrepo with name:   #
#  - MODULENAME                                               #
# 3. The CVS module is on ./cvsrepo/module_name               #
#                                                             #
###############################################################

clear

module=""
trunk=""
pwd=$PWD

export CVSROOT=$PWD/cvsrepo
bzrroot=$PWD/bzrrepo
cvsroot=$CVSROOT
echo "CVSROOT = $CVSROOT"
echo "BZRROOT = $bzrroot"

# Set the timezone to GMT
tz=$TZ
export TZ=GMT

# Test if the module name is passed as a parameter
if [ $# != 1 ] ; then
   echo "Usage: s1-convertnotags.sh module_name"
   exit 1
else
   module=$1   
fi

###############################################################
#                      STAGE 1                                #
#                                                             #
# verify parameters and create a new repository               #
#                                                             #
###############################################################

# Test if the module exists in the repository
if [ ! -d $cvsroot/$module ]
then
   echo "$cvsroot/$module does not exist.";
   exit 1
fi

# Test if the cvs2bzr option file is in place
if [ ! -f cvs2bzr-$module.options ] ;then
   echo "The ./cvs2bzr-$module.options file does not exist"
   exit 1
fi

# If there is a bazaar repo then stop
if [ -d $bzrroot/$module ] ;then
   echo "The $bzrroot/$module directory already exists"
   exit 1
fi

# Create the bazaar repository
mkdir $bzrroot/$module
cd $bzrroot
bzr init-repo $module
bzr init $module/$trunk
bzr nick $module
cd $pwd

# Starting conversion
echo "Starting conversion ..."

###############################################################
#                      STAGE 2                                #
#                                                             #
# convert from cvs into bzr repo "modulename" with no tags    #
# using cvs2bzr and fastimport
#                                                             #
###############################################################

mkdir -p cvs2svn-2.4.0/cvs2svn-tmp

# Export from CVS in fi
cd $pwd/cvs2svn-2.4.0
./cvs2bzr --options=../cvs2bzr-$module.options

# make a backup
cp -f ./cvs2svn-tmp/dumpfile.fi ./cvs2svn-tmp/$module.fi

# Import from fi in BZR
bzr fast-import ./cvs2svn-tmp/dumpfile.fi $bzrroot/$module

echo "Bazaar repository created : $bzrroot/$module"
echo "Done."

