#!/bin/bash
###############################################################
#
#     Format:   s34-applytags.sh module_name file_name
# 
#  - this script will tag the module module_name from a bazaar 
#    repository assumed to be on ./bzrrepo with tags from the file
#    file_name with the following columns:
#    $1     $2      $3       $4        $5 ...
#    TAG     *       *       DATE      TIME
#
# Prerequisites:
# - a BZR repository located in ./bzrrepo
# - a file previously generated with a s3-detecttime[-alt].sh 
#
###############################################################

module="" 
filename=""
tag=""
trunk=""
pwd=$PWD
workdir=$pwd/tmp-applytags

bzrroot=$PWD/bzrrepo

export TZ=GMT

# Test if the module name and file name are passed as parameters
if [ $# != 2 ] ; then
   echo "Usage: s4-applytags.sh module_name file_name"
   exit 1
else
   module=$1 
   filename=$2  
fi

# Test if bazaar module and file exist
if [ ! -d $bzrroot/$module ] ; then 
   echo "$bzrroot/$module does not exist."; 
   exit 1
fi
if [ ! -f $file_name ] ; then  
   echo "$file_name does not exist."; 
   exit 1 
fi

# Checkout from BZR
rm -fr $workdir
mkdir $workdir
mkdir $workdir/$module
cd $workdir/$module 

bzr checkout $bzrroot/$module/$trunk .

# Tag the revision
awk '{print "Aplly TAG: " $1} {system( "bzr tag -r before:date:"$4","$5" "$1 )}' $pwd/$filename
